@@ -1,4 +1,4 @@
-# Copyright (c) 2020, 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2020 - 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -92,9 +92,11 @@ For example, the following schema:
     }
 """
 
-from typing import Any, Dict, List, Tuple  # noqa: H301
+from __future__ import annotations
 
-VERSION = "1.1.0"
+from typing import Any, Dict, Tuple
+
+VERSION = "1.1.1"
 
 FEATURES_STRING = "trivval=" + VERSION
 
@@ -108,7 +110,7 @@ SchemaType = Dict[Tuple[int, int], Dict[str, Any]]
 class ValidationError(Exception):
     """Signal an error that occurred during the validation."""
 
-    def __init__(self, path: List[str], err: str) -> None:
+    def __init__(self, path: list[str], err: str) -> None:
         self.path = path
         self.err = err
         suffix = "" if not self.path else ": " + "/".join(path)
@@ -136,14 +138,10 @@ def validate_single(key: str, item: Any, schema: Any, flags: int) -> None:
             raise ValidationError([key] + err.path, err.err) from err
 
 
-def validate_list(
-    key: str, value: List[Any], schema: List[Any], flags: int
-) -> None:
+def validate_list(key: str, value: list[Any], schema: list[Any], flags: int) -> None:
     """Validate a list against a single-element schema."""
     if not isinstance(value, list):
-        raise ValidationError(
-            [key], f"not a list, {type(value).__name__} instead".__name__
-        )
+        raise ValidationError([key], f"not a list, {type(value).__name__} instead")
 
     assert len(schema) == 1
     for index, item in enumerate(value):
@@ -155,12 +153,10 @@ def validate_list(
         )
 
 
-def validate_dict(value: Any, schema: Dict[str, Any], flags: int) -> None:
+def validate_dict(value: Any, schema: dict[str, Any], flags: int) -> None:
     """Validate a dictionary against a schema."""
     if not isinstance(value, dict):
-        raise ValidationError(
-            [], f"not a dictionary, {type(value).__name__} instead"
-        )
+        raise ValidationError([], f"not a dictionary, {type(value).__name__} instead")
 
     if len(schema.keys()) == 1 and "*" in schema:
         valtype = schema["*"]
@@ -187,9 +183,7 @@ def validate_dict(value: Any, schema: Dict[str, Any], flags: int) -> None:
         raise ValidationError([",".join(sorted(extra))], "extra keys")
 
 
-def validate(
-    value: Dict[str, Any], schemas: SchemaType, flags: int = 0
-) -> None:
+def validate(value: dict[str, Any], schemas: SchemaType, flags: int = 0) -> None:
     """Validate a dictionary against the appropriate schema."""
     try:
         validate_dict(value, SCHEMA_FORMAT, FLAG_ALLOW_EXTRA)
@@ -207,13 +201,9 @@ def validate(
     stripped = {key: val for key, val in value.items() if key != "format"}
 
     same_major = sorted(
-        ver
-        for ver in schemas.keys()
-        if ver[0] == version[0] and ver[1] <= version[1]
+        ver for ver in schemas.keys() if ver[0] == version[0] and ver[1] <= version[1]
     )
     if not same_major:
-        raise ValidationError(
-            ["format", "version"], "unsupported format version"
-        )
+        raise ValidationError(["format", "version"], "unsupported format version")
 
     validate_dict(stripped, schemas[same_major[-1]], flags)
