@@ -46,9 +46,7 @@ SCHEMA_1_1 = {
             "server": {"timestamp": int, "instances": int},
         },
     },
-    "users": {
-        "*": {"first_name": str, "last_name": str, "id": int, "?nickname": str}
-    },
+    "users": {"*": {"first_name": str, "last_name": str, "id": int, "?nickname": str}},
     "tags": [str],
 }
 
